# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chia_tea/protobuf/generated/monitoring_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from chia_tea.protobuf.generated import computer_info_pb2 as chia__tea_dot_protobuf_dot_generated_dot_computer__info__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='chia_tea/protobuf/generated/monitoring_service.proto',
  package='chia_tea.protobuf.generated.monitoring_service_pb2',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4chia_tea/protobuf/generated/monitoring_service.proto\x12\x32\x63hia_tea.protobuf.generated.monitoring_service_pb2\x1a\x1bgoogle/protobuf/empty.proto\x1a/chia_tea/protobuf/generated/computer_info.proto\"%\n\x0fGetStateRequest\x12\x12\n\nmachine_id\x18\x01 \x01(\x03\"\x9c\x01\n\x11\x44\x61taUpdateRequest\x12\x12\n\nmachine_id\x18\x01 \x01(\x03\x12\x14\n\x0cmachine_name\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x01\x12J\n\x06\x65vents\x18\x03 \x03(\x0b\x32:.chia_tea.protobuf.generated.computer_info_pb2.UpdateEvent2\x9d\x02\n\nMonitoring\x12\x93\x01\n\x0fGetMachineState\x12\x43.chia_tea.protobuf.generated.monitoring_service_pb2.GetStateRequest\x1a;.chia_tea.protobuf.generated.computer_info_pb2.ComputerInfo\x12y\n\x14SendMonitoringUpdate\x12\x45.chia_tea.protobuf.generated.monitoring_service_pb2.DataUpdateRequest\x1a\x16.google.protobuf.Empty(\x01\x30\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,chia__tea_dot_protobuf_dot_generated_dot_computer__info__pb2.DESCRIPTOR,])




_GETSTATEREQUEST = _descriptor.Descriptor(
  name='GetStateRequest',
  full_name='chia_tea.protobuf.generated.monitoring_service_pb2.GetStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='machine_id', full_name='chia_tea.protobuf.generated.monitoring_service_pb2.GetStateRequest.machine_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=223,
)


_DATAUPDATEREQUEST = _descriptor.Descriptor(
  name='DataUpdateRequest',
  full_name='chia_tea.protobuf.generated.monitoring_service_pb2.DataUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='machine_id', full_name='chia_tea.protobuf.generated.monitoring_service_pb2.DataUpdateRequest.machine_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='machine_name', full_name='chia_tea.protobuf.generated.monitoring_service_pb2.DataUpdateRequest.machine_name', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='chia_tea.protobuf.generated.monitoring_service_pb2.DataUpdateRequest.timestamp', index=2,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='events', full_name='chia_tea.protobuf.generated.monitoring_service_pb2.DataUpdateRequest.events', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=382,
)

_DATAUPDATEREQUEST.fields_by_name['events'].message_type = chia__tea_dot_protobuf_dot_generated_dot_computer__info__pb2._UPDATEEVENT
DESCRIPTOR.message_types_by_name['GetStateRequest'] = _GETSTATEREQUEST
DESCRIPTOR.message_types_by_name['DataUpdateRequest'] = _DATAUPDATEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetStateRequest = _reflection.GeneratedProtocolMessageType('GetStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATEREQUEST,
  '__module__' : 'chia_tea.protobuf.generated.monitoring_service_pb2'
  # @@protoc_insertion_point(class_scope:chia_tea.protobuf.generated.monitoring_service_pb2.GetStateRequest)
  })
_sym_db.RegisterMessage(GetStateRequest)

DataUpdateRequest = _reflection.GeneratedProtocolMessageType('DataUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATAUPDATEREQUEST,
  '__module__' : 'chia_tea.protobuf.generated.monitoring_service_pb2'
  # @@protoc_insertion_point(class_scope:chia_tea.protobuf.generated.monitoring_service_pb2.DataUpdateRequest)
  })
_sym_db.RegisterMessage(DataUpdateRequest)



_MONITORING = _descriptor.ServiceDescriptor(
  name='Monitoring',
  full_name='chia_tea.protobuf.generated.monitoring_service_pb2.Monitoring',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=385,
  serialized_end=670,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetMachineState',
    full_name='chia_tea.protobuf.generated.monitoring_service_pb2.Monitoring.GetMachineState',
    index=0,
    containing_service=None,
    input_type=_GETSTATEREQUEST,
    output_type=chia__tea_dot_protobuf_dot_generated_dot_computer__info__pb2._COMPUTERINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendMonitoringUpdate',
    full_name='chia_tea.protobuf.generated.monitoring_service_pb2.Monitoring.SendMonitoringUpdate',
    index=1,
    containing_service=None,
    input_type=_DATAUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MONITORING)

DESCRIPTOR.services_by_name['Monitoring'] = _MONITORING

# @@protoc_insertion_point(module_scope)
