# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chia_tea/protobuf/generated/computer_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from chia_tea.protobuf.generated import hardware_pb2 as chia__tea_dot_protobuf_dot_generated_dot_hardware__pb2
from chia_tea.protobuf.generated import chia_pb2 as chia__tea_dot_protobuf_dot_generated_dot_chia__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='chia_tea/protobuf/generated/computer_info.proto',
  package='chia_tea.protobuf.generated.computer_info_pb2',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/chia_tea/protobuf/generated/computer_info.proto\x12-chia_tea.protobuf.generated.computer_info_pb2\x1a*chia_tea/protobuf/generated/hardware.proto\x1a&chia_tea/protobuf/generated/chia.proto\"\xe6\x05\n\x0c\x43omputerInfo\x12\x11\n\ttimestamp\x18\x01 \x01(\x01\x12\x12\n\nmachine_id\x18\x02 \x01(\x03\x12:\n\x03\x63pu\x18\x03 \x01(\x0b\x32-.chia_tea.protobuf.generated.hardware_pb2.Cpu\x12:\n\x03ram\x18\x04 \x01(\x0b\x32-.chia_tea.protobuf.generated.hardware_pb2.Ram\x12=\n\x05\x64isks\x18\x05 \x03(\x0b\x32..chia_tea.protobuf.generated.hardware_pb2.Disk\x12L\n\x0eplotting_plots\x18\x06 \x03(\x0b\x32\x34.chia_tea.protobuf.generated.chia_pb2.PlotInProgress\x12<\n\x06\x66\x61rmer\x18\x07 \x01(\x0b\x32,.chia_tea.protobuf.generated.chia_pb2.Farmer\x12Z\n\x11\x66\x61rmer_harvesters\x18\x08 \x03(\x0b\x32?.chia_tea.protobuf.generated.chia_pb2.HarvesterViewedFromFarmer\x12\x42\n\tharvester\x18\t \x01(\x0b\x32/.chia_tea.protobuf.generated.chia_pb2.Harvester\x12L\n\x0fharvester_plots\x18\n \x03(\x0b\x32\x33.chia_tea.protobuf.generated.chia_pb2.HarvesterPlot\x12<\n\x06wallet\x18\x0b \x01(\x0b\x32,.chia_tea.protobuf.generated.chia_pb2.Wallet\x12@\n\tprocesses\x18\x0c \x03(\x0b\x32-.chia_tea.protobuf.generated.chia_pb2.Process\"\xa8\x06\n\x0bUpdateEvent\x12L\n\nevent_type\x18\x03 \x01(\x0e\x32\x38.chia_tea.protobuf.generated.computer_info_pb2.EventType\x12<\n\x03\x63pu\x18\x04 \x01(\x0b\x32-.chia_tea.protobuf.generated.hardware_pb2.CpuH\x00\x12<\n\x03ram\x18\x05 \x01(\x0b\x32-.chia_tea.protobuf.generated.hardware_pb2.RamH\x00\x12>\n\x04\x64isk\x18\x06 \x01(\x0b\x32..chia_tea.protobuf.generated.hardware_pb2.DiskH\x00\x12>\n\x06\x66\x61rmer\x18\x07 \x01(\x0b\x32,.chia_tea.protobuf.generated.chia_pb2.FarmerH\x00\x12[\n\x10\x66\x61rmer_harvester\x18\x08 \x01(\x0b\x32?.chia_tea.protobuf.generated.chia_pb2.HarvesterViewedFromFarmerH\x00\x12M\n\x0eharvester_plot\x18\r \x01(\x0b\x32\x33.chia_tea.protobuf.generated.chia_pb2.HarvesterPlotH\x00\x12\x44\n\tharvester\x18\t \x01(\x0b\x32/.chia_tea.protobuf.generated.chia_pb2.HarvesterH\x00\x12>\n\x06wallet\x18\n \x01(\x0b\x32,.chia_tea.protobuf.generated.chia_pb2.WalletH\x00\x12@\n\x07process\x18\x0b \x01(\x0b\x32-.chia_tea.protobuf.generated.chia_pb2.ProcessH\x00\x12M\n\rplotting_plot\x18\x0c \x01(\x0b\x32\x34.chia_tea.protobuf.generated.chia_pb2.PlotInProgressH\x00\x42\x0c\n\nevent_data*6\n\tEventType\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\x62\x06proto3'
  ,
  dependencies=[chia__tea_dot_protobuf_dot_generated_dot_hardware__pb2.DESCRIPTOR,chia__tea_dot_protobuf_dot_generated_dot_chia__pb2.DESCRIPTOR,])

_EVENTTYPE = _descriptor.EnumDescriptor(
  name='EventType',
  full_name='chia_tea.protobuf.generated.computer_info_pb2.EventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPDATE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1738,
  serialized_end=1792,
)
_sym_db.RegisterEnumDescriptor(_EVENTTYPE)

EventType = enum_type_wrapper.EnumTypeWrapper(_EVENTTYPE)
NONE = 0
ADD = 1
UPDATE = 2
DELETE = 3



_COMPUTERINFO = _descriptor.Descriptor(
  name='ComputerInfo',
  full_name='chia_tea.protobuf.generated.computer_info_pb2.ComputerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='chia_tea.protobuf.generated.computer_info_pb2.ComputerInfo.timestamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='machine_id', full_name='chia_tea.protobuf.generated.computer_info_pb2.ComputerInfo.machine_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu', full_name='chia_tea.protobuf.generated.computer_info_pb2.ComputerInfo.cpu', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ram', full_name='chia_tea.protobuf.generated.computer_info_pb2.ComputerInfo.ram', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disks', full_name='chia_tea.protobuf.generated.computer_info_pb2.ComputerInfo.disks', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plotting_plots', full_name='chia_tea.protobuf.generated.computer_info_pb2.ComputerInfo.plotting_plots', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='farmer', full_name='chia_tea.protobuf.generated.computer_info_pb2.ComputerInfo.farmer', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='farmer_harvesters', full_name='chia_tea.protobuf.generated.computer_info_pb2.ComputerInfo.farmer_harvesters', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='harvester', full_name='chia_tea.protobuf.generated.computer_info_pb2.ComputerInfo.harvester', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='harvester_plots', full_name='chia_tea.protobuf.generated.computer_info_pb2.ComputerInfo.harvester_plots', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wallet', full_name='chia_tea.protobuf.generated.computer_info_pb2.ComputerInfo.wallet', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processes', full_name='chia_tea.protobuf.generated.computer_info_pb2.ComputerInfo.processes', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=925,
)


_UPDATEEVENT = _descriptor.Descriptor(
  name='UpdateEvent',
  full_name='chia_tea.protobuf.generated.computer_info_pb2.UpdateEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_type', full_name='chia_tea.protobuf.generated.computer_info_pb2.UpdateEvent.event_type', index=0,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu', full_name='chia_tea.protobuf.generated.computer_info_pb2.UpdateEvent.cpu', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ram', full_name='chia_tea.protobuf.generated.computer_info_pb2.UpdateEvent.ram', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk', full_name='chia_tea.protobuf.generated.computer_info_pb2.UpdateEvent.disk', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='farmer', full_name='chia_tea.protobuf.generated.computer_info_pb2.UpdateEvent.farmer', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='farmer_harvester', full_name='chia_tea.protobuf.generated.computer_info_pb2.UpdateEvent.farmer_harvester', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='harvester_plot', full_name='chia_tea.protobuf.generated.computer_info_pb2.UpdateEvent.harvester_plot', index=6,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='harvester', full_name='chia_tea.protobuf.generated.computer_info_pb2.UpdateEvent.harvester', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wallet', full_name='chia_tea.protobuf.generated.computer_info_pb2.UpdateEvent.wallet', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process', full_name='chia_tea.protobuf.generated.computer_info_pb2.UpdateEvent.process', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plotting_plot', full_name='chia_tea.protobuf.generated.computer_info_pb2.UpdateEvent.plotting_plot', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event_data', full_name='chia_tea.protobuf.generated.computer_info_pb2.UpdateEvent.event_data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=928,
  serialized_end=1736,
)

_COMPUTERINFO.fields_by_name['cpu'].message_type = chia__tea_dot_protobuf_dot_generated_dot_hardware__pb2._CPU
_COMPUTERINFO.fields_by_name['ram'].message_type = chia__tea_dot_protobuf_dot_generated_dot_hardware__pb2._RAM
_COMPUTERINFO.fields_by_name['disks'].message_type = chia__tea_dot_protobuf_dot_generated_dot_hardware__pb2._DISK
_COMPUTERINFO.fields_by_name['plotting_plots'].message_type = chia__tea_dot_protobuf_dot_generated_dot_chia__pb2._PLOTINPROGRESS
_COMPUTERINFO.fields_by_name['farmer'].message_type = chia__tea_dot_protobuf_dot_generated_dot_chia__pb2._FARMER
_COMPUTERINFO.fields_by_name['farmer_harvesters'].message_type = chia__tea_dot_protobuf_dot_generated_dot_chia__pb2._HARVESTERVIEWEDFROMFARMER
_COMPUTERINFO.fields_by_name['harvester'].message_type = chia__tea_dot_protobuf_dot_generated_dot_chia__pb2._HARVESTER
_COMPUTERINFO.fields_by_name['harvester_plots'].message_type = chia__tea_dot_protobuf_dot_generated_dot_chia__pb2._HARVESTERPLOT
_COMPUTERINFO.fields_by_name['wallet'].message_type = chia__tea_dot_protobuf_dot_generated_dot_chia__pb2._WALLET
_COMPUTERINFO.fields_by_name['processes'].message_type = chia__tea_dot_protobuf_dot_generated_dot_chia__pb2._PROCESS
_UPDATEEVENT.fields_by_name['event_type'].enum_type = _EVENTTYPE
_UPDATEEVENT.fields_by_name['cpu'].message_type = chia__tea_dot_protobuf_dot_generated_dot_hardware__pb2._CPU
_UPDATEEVENT.fields_by_name['ram'].message_type = chia__tea_dot_protobuf_dot_generated_dot_hardware__pb2._RAM
_UPDATEEVENT.fields_by_name['disk'].message_type = chia__tea_dot_protobuf_dot_generated_dot_hardware__pb2._DISK
_UPDATEEVENT.fields_by_name['farmer'].message_type = chia__tea_dot_protobuf_dot_generated_dot_chia__pb2._FARMER
_UPDATEEVENT.fields_by_name['farmer_harvester'].message_type = chia__tea_dot_protobuf_dot_generated_dot_chia__pb2._HARVESTERVIEWEDFROMFARMER
_UPDATEEVENT.fields_by_name['harvester_plot'].message_type = chia__tea_dot_protobuf_dot_generated_dot_chia__pb2._HARVESTERPLOT
_UPDATEEVENT.fields_by_name['harvester'].message_type = chia__tea_dot_protobuf_dot_generated_dot_chia__pb2._HARVESTER
_UPDATEEVENT.fields_by_name['wallet'].message_type = chia__tea_dot_protobuf_dot_generated_dot_chia__pb2._WALLET
_UPDATEEVENT.fields_by_name['process'].message_type = chia__tea_dot_protobuf_dot_generated_dot_chia__pb2._PROCESS
_UPDATEEVENT.fields_by_name['plotting_plot'].message_type = chia__tea_dot_protobuf_dot_generated_dot_chia__pb2._PLOTINPROGRESS
_UPDATEEVENT.oneofs_by_name['event_data'].fields.append(
  _UPDATEEVENT.fields_by_name['cpu'])
_UPDATEEVENT.fields_by_name['cpu'].containing_oneof = _UPDATEEVENT.oneofs_by_name['event_data']
_UPDATEEVENT.oneofs_by_name['event_data'].fields.append(
  _UPDATEEVENT.fields_by_name['ram'])
_UPDATEEVENT.fields_by_name['ram'].containing_oneof = _UPDATEEVENT.oneofs_by_name['event_data']
_UPDATEEVENT.oneofs_by_name['event_data'].fields.append(
  _UPDATEEVENT.fields_by_name['disk'])
_UPDATEEVENT.fields_by_name['disk'].containing_oneof = _UPDATEEVENT.oneofs_by_name['event_data']
_UPDATEEVENT.oneofs_by_name['event_data'].fields.append(
  _UPDATEEVENT.fields_by_name['farmer'])
_UPDATEEVENT.fields_by_name['farmer'].containing_oneof = _UPDATEEVENT.oneofs_by_name['event_data']
_UPDATEEVENT.oneofs_by_name['event_data'].fields.append(
  _UPDATEEVENT.fields_by_name['farmer_harvester'])
_UPDATEEVENT.fields_by_name['farmer_harvester'].containing_oneof = _UPDATEEVENT.oneofs_by_name['event_data']
_UPDATEEVENT.oneofs_by_name['event_data'].fields.append(
  _UPDATEEVENT.fields_by_name['harvester_plot'])
_UPDATEEVENT.fields_by_name['harvester_plot'].containing_oneof = _UPDATEEVENT.oneofs_by_name['event_data']
_UPDATEEVENT.oneofs_by_name['event_data'].fields.append(
  _UPDATEEVENT.fields_by_name['harvester'])
_UPDATEEVENT.fields_by_name['harvester'].containing_oneof = _UPDATEEVENT.oneofs_by_name['event_data']
_UPDATEEVENT.oneofs_by_name['event_data'].fields.append(
  _UPDATEEVENT.fields_by_name['wallet'])
_UPDATEEVENT.fields_by_name['wallet'].containing_oneof = _UPDATEEVENT.oneofs_by_name['event_data']
_UPDATEEVENT.oneofs_by_name['event_data'].fields.append(
  _UPDATEEVENT.fields_by_name['process'])
_UPDATEEVENT.fields_by_name['process'].containing_oneof = _UPDATEEVENT.oneofs_by_name['event_data']
_UPDATEEVENT.oneofs_by_name['event_data'].fields.append(
  _UPDATEEVENT.fields_by_name['plotting_plot'])
_UPDATEEVENT.fields_by_name['plotting_plot'].containing_oneof = _UPDATEEVENT.oneofs_by_name['event_data']
DESCRIPTOR.message_types_by_name['ComputerInfo'] = _COMPUTERINFO
DESCRIPTOR.message_types_by_name['UpdateEvent'] = _UPDATEEVENT
DESCRIPTOR.enum_types_by_name['EventType'] = _EVENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ComputerInfo = _reflection.GeneratedProtocolMessageType('ComputerInfo', (_message.Message,), {
  'DESCRIPTOR' : _COMPUTERINFO,
  '__module__' : 'chia_tea.protobuf.generated.computer_info_pb2'
  # @@protoc_insertion_point(class_scope:chia_tea.protobuf.generated.computer_info_pb2.ComputerInfo)
  })
_sym_db.RegisterMessage(ComputerInfo)

UpdateEvent = _reflection.GeneratedProtocolMessageType('UpdateEvent', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEVENT,
  '__module__' : 'chia_tea.protobuf.generated.computer_info_pb2'
  # @@protoc_insertion_point(class_scope:chia_tea.protobuf.generated.computer_info_pb2.UpdateEvent)
  })
_sym_db.RegisterMessage(UpdateEvent)


# @@protoc_insertion_point(module_scope)
