# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chia_tea/protobuf/generated/config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='chia_tea/protobuf/generated/config.proto',
  package='chia_tea.protobuf.generated.config_pb2',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(chia_tea/protobuf/generated/config.proto\x12&chia_tea.protobuf.generated.config_pb2\"\x1d\n\rMachineConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xb3\x01\n\rLoggingConfig\x12\x42\n\x08loglevel\x18\x01 \x01(\x0e\x32\x30.chia_tea.protobuf.generated.config_pb2.LogLevel\x12\x16\n\x0elog_to_console\x18\x02 \x01(\x08\x12\x13\n\x0blog_to_file\x18\x03 \x01(\x08\x12\x14\n\x0cmax_logfiles\x18\x04 \x01(\x05\x12\x1b\n\x13max_logfile_size_mb\x18\x05 \x01(\x05\"<\n\nCopyConfig\x12\x16\n\x0esource_folders\x18\x01 \x03(\t\x12\x16\n\x0etarget_folders\x18\x02 \x03(\t\">\n\nChiaConfig\x12\x18\n\x10logfile_filepath\x18\x01 \x01(\t\x12\x16\n\x0emadmax_logfile\x18\x02 \x01(\t\"2\n\rDiscordConfig\x12\r\n\x05token\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\x03\"\x88\x06\n\x10MonitoringConfig\x12Q\n\x04\x61uth\x18\x01 \x01(\x0b\x32\x43.chia_tea.protobuf.generated.config_pb2.MonitoringConfig.AuthConfig\x12U\n\x06server\x18\x02 \x01(\x0b\x32\x45.chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ServerConfig\x12U\n\x06\x63lient\x18\x03 \x01(\x0b\x32\x45.chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig\x1a\x39\n\nAuthConfig\x12\x15\n\rcert_filepath\x18\x01 \x01(\t\x12\x14\n\x0ckey_filepath\x18\x02 \x01(\t\x1a\x31\n\x0cServerConfig\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\x13\n\x0b\x64\x62_filepath\x18\x02 \x01(\t\x1a\x84\x03\n\x0c\x43lientConfig\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x1a\n\x12\x63ollect_data_every\x18\x03 \x01(\x01\x12p\n\x11send_update_every\x18\x04 \x01(\x0b\x32U.chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig.SendUpdateEvery\x1a\xc6\x01\n\x0fSendUpdateEvery\x12\x0b\n\x03\x63pu\x18\x01 \x01(\x01\x12\x0b\n\x03ram\x18\x02 \x01(\x01\x12\x0c\n\x04\x64isk\x18\x03 \x01(\x01\x12\x0f\n\x07process\x18\x04 \x01(\x01\x12\x0e\n\x06\x66\x61rmer\x18\x05 \x01(\x01\x12\x18\n\x10\x66\x61rmer_harvester\x18\x06 \x01(\x01\x12\x11\n\tharvester\x18\x07 \x01(\x01\x12\x0e\n\x06wallet\x18\x08 \x01(\x01\x12\x15\n\rplotting_plot\x18\t \x01(\x01\x12\x16\n\x0eharvester_plot\x18\n \x01(\x01\"J\n\x11\x44\x65velopmentConfig\x12\x0f\n\x07testing\x18\x01 \x01(\x08\x12$\n\x1cmonitoring_client_state_file\x18\x02 \x01(\t\"\x9a\x04\n\rChiaTeaConfig\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12\x46\n\x07machine\x18\x08 \x01(\x0b\x32\x35.chia_tea.protobuf.generated.config_pb2.MachineConfig\x12\x46\n\x07logging\x18\x02 \x01(\x0b\x32\x35.chia_tea.protobuf.generated.config_pb2.LoggingConfig\x12@\n\x04\x63opy\x18\x03 \x01(\x0b\x32\x32.chia_tea.protobuf.generated.config_pb2.CopyConfig\x12@\n\x04\x63hia\x18\x04 \x01(\x0b\x32\x32.chia_tea.protobuf.generated.config_pb2.ChiaConfig\x12\x46\n\x07\x64iscord\x18\x05 \x01(\x0b\x32\x35.chia_tea.protobuf.generated.config_pb2.DiscordConfig\x12L\n\nmonitoring\x18\x06 \x01(\x0b\x32\x38.chia_tea.protobuf.generated.config_pb2.MonitoringConfig\x12N\n\x0b\x64\x65velopment\x18\x07 \x01(\x0b\x32\x39.chia_tea.protobuf.generated.config_pb2.DevelopmentConfig*B\n\x08LogLevel\x12\t\n\x05TRACE\x10\x00\x12\t\n\x05\x44\x45\x42UG\x10\x01\x12\x08\n\x04INFO\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x62\x06proto3'
)

_LOGLEVEL = _descriptor.EnumDescriptor(
  name='LogLevel',
  full_name='chia_tea.protobuf.generated.config_pb2.LogLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRACE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEBUG', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INFO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1871,
  serialized_end=1937,
)
_sym_db.RegisterEnumDescriptor(_LOGLEVEL)

LogLevel = enum_type_wrapper.EnumTypeWrapper(_LOGLEVEL)
TRACE = 0
DEBUG = 1
INFO = 2
WARNING = 3
ERROR = 4



_MACHINECONFIG = _descriptor.Descriptor(
  name='MachineConfig',
  full_name='chia_tea.protobuf.generated.config_pb2.MachineConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='chia_tea.protobuf.generated.config_pb2.MachineConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=113,
)


_LOGGINGCONFIG = _descriptor.Descriptor(
  name='LoggingConfig',
  full_name='chia_tea.protobuf.generated.config_pb2.LoggingConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loglevel', full_name='chia_tea.protobuf.generated.config_pb2.LoggingConfig.loglevel', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_to_console', full_name='chia_tea.protobuf.generated.config_pb2.LoggingConfig.log_to_console', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_to_file', full_name='chia_tea.protobuf.generated.config_pb2.LoggingConfig.log_to_file', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_logfiles', full_name='chia_tea.protobuf.generated.config_pb2.LoggingConfig.max_logfiles', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_logfile_size_mb', full_name='chia_tea.protobuf.generated.config_pb2.LoggingConfig.max_logfile_size_mb', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=295,
)


_COPYCONFIG = _descriptor.Descriptor(
  name='CopyConfig',
  full_name='chia_tea.protobuf.generated.config_pb2.CopyConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_folders', full_name='chia_tea.protobuf.generated.config_pb2.CopyConfig.source_folders', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_folders', full_name='chia_tea.protobuf.generated.config_pb2.CopyConfig.target_folders', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=297,
  serialized_end=357,
)


_CHIACONFIG = _descriptor.Descriptor(
  name='ChiaConfig',
  full_name='chia_tea.protobuf.generated.config_pb2.ChiaConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='logfile_filepath', full_name='chia_tea.protobuf.generated.config_pb2.ChiaConfig.logfile_filepath', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='madmax_logfile', full_name='chia_tea.protobuf.generated.config_pb2.ChiaConfig.madmax_logfile', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=359,
  serialized_end=421,
)


_DISCORDCONFIG = _descriptor.Descriptor(
  name='DiscordConfig',
  full_name='chia_tea.protobuf.generated.config_pb2.DiscordConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='chia_tea.protobuf.generated.config_pb2.DiscordConfig.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='chia_tea.protobuf.generated.config_pb2.DiscordConfig.channel_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=473,
)


_MONITORINGCONFIG_AUTHCONFIG = _descriptor.Descriptor(
  name='AuthConfig',
  full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.AuthConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cert_filepath', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.AuthConfig.cert_filepath', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_filepath', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.AuthConfig.key_filepath', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=753,
  serialized_end=810,
)

_MONITORINGCONFIG_SERVERCONFIG = _descriptor.Descriptor(
  name='ServerConfig',
  full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ServerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ServerConfig.port', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='db_filepath', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ServerConfig.db_filepath', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=812,
  serialized_end=861,
)

_MONITORINGCONFIG_CLIENTCONFIG_SENDUPDATEEVERY = _descriptor.Descriptor(
  name='SendUpdateEvery',
  full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig.SendUpdateEvery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cpu', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig.SendUpdateEvery.cpu', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ram', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig.SendUpdateEvery.ram', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig.SendUpdateEvery.disk', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig.SendUpdateEvery.process', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='farmer', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig.SendUpdateEvery.farmer', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='farmer_harvester', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig.SendUpdateEvery.farmer_harvester', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='harvester', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig.SendUpdateEvery.harvester', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wallet', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig.SendUpdateEvery.wallet', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plotting_plot', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig.SendUpdateEvery.plotting_plot', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='harvester_plot', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig.SendUpdateEvery.harvester_plot', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1054,
  serialized_end=1252,
)

_MONITORINGCONFIG_CLIENTCONFIG = _descriptor.Descriptor(
  name='ClientConfig',
  full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig.port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collect_data_every', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig.collect_data_every', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_update_every', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig.send_update_every', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONITORINGCONFIG_CLIENTCONFIG_SENDUPDATEEVERY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=864,
  serialized_end=1252,
)

_MONITORINGCONFIG = _descriptor.Descriptor(
  name='MonitoringConfig',
  full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auth', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.auth', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.server', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client', full_name='chia_tea.protobuf.generated.config_pb2.MonitoringConfig.client', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONITORINGCONFIG_AUTHCONFIG, _MONITORINGCONFIG_SERVERCONFIG, _MONITORINGCONFIG_CLIENTCONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=476,
  serialized_end=1252,
)


_DEVELOPMENTCONFIG = _descriptor.Descriptor(
  name='DevelopmentConfig',
  full_name='chia_tea.protobuf.generated.config_pb2.DevelopmentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='testing', full_name='chia_tea.protobuf.generated.config_pb2.DevelopmentConfig.testing', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitoring_client_state_file', full_name='chia_tea.protobuf.generated.config_pb2.DevelopmentConfig.monitoring_client_state_file', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1254,
  serialized_end=1328,
)


_CHIATEACONFIG = _descriptor.Descriptor(
  name='ChiaTeaConfig',
  full_name='chia_tea.protobuf.generated.config_pb2.ChiaTeaConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='chia_tea.protobuf.generated.config_pb2.ChiaTeaConfig.version', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='machine', full_name='chia_tea.protobuf.generated.config_pb2.ChiaTeaConfig.machine', index=1,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logging', full_name='chia_tea.protobuf.generated.config_pb2.ChiaTeaConfig.logging', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='copy', full_name='chia_tea.protobuf.generated.config_pb2.ChiaTeaConfig.copy', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chia', full_name='chia_tea.protobuf.generated.config_pb2.ChiaTeaConfig.chia', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discord', full_name='chia_tea.protobuf.generated.config_pb2.ChiaTeaConfig.discord', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitoring', full_name='chia_tea.protobuf.generated.config_pb2.ChiaTeaConfig.monitoring', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='development', full_name='chia_tea.protobuf.generated.config_pb2.ChiaTeaConfig.development', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1331,
  serialized_end=1869,
)

_LOGGINGCONFIG.fields_by_name['loglevel'].enum_type = _LOGLEVEL
_MONITORINGCONFIG_AUTHCONFIG.containing_type = _MONITORINGCONFIG
_MONITORINGCONFIG_SERVERCONFIG.containing_type = _MONITORINGCONFIG
_MONITORINGCONFIG_CLIENTCONFIG_SENDUPDATEEVERY.containing_type = _MONITORINGCONFIG_CLIENTCONFIG
_MONITORINGCONFIG_CLIENTCONFIG.fields_by_name['send_update_every'].message_type = _MONITORINGCONFIG_CLIENTCONFIG_SENDUPDATEEVERY
_MONITORINGCONFIG_CLIENTCONFIG.containing_type = _MONITORINGCONFIG
_MONITORINGCONFIG.fields_by_name['auth'].message_type = _MONITORINGCONFIG_AUTHCONFIG
_MONITORINGCONFIG.fields_by_name['server'].message_type = _MONITORINGCONFIG_SERVERCONFIG
_MONITORINGCONFIG.fields_by_name['client'].message_type = _MONITORINGCONFIG_CLIENTCONFIG
_CHIATEACONFIG.fields_by_name['machine'].message_type = _MACHINECONFIG
_CHIATEACONFIG.fields_by_name['logging'].message_type = _LOGGINGCONFIG
_CHIATEACONFIG.fields_by_name['copy'].message_type = _COPYCONFIG
_CHIATEACONFIG.fields_by_name['chia'].message_type = _CHIACONFIG
_CHIATEACONFIG.fields_by_name['discord'].message_type = _DISCORDCONFIG
_CHIATEACONFIG.fields_by_name['monitoring'].message_type = _MONITORINGCONFIG
_CHIATEACONFIG.fields_by_name['development'].message_type = _DEVELOPMENTCONFIG
DESCRIPTOR.message_types_by_name['MachineConfig'] = _MACHINECONFIG
DESCRIPTOR.message_types_by_name['LoggingConfig'] = _LOGGINGCONFIG
DESCRIPTOR.message_types_by_name['CopyConfig'] = _COPYCONFIG
DESCRIPTOR.message_types_by_name['ChiaConfig'] = _CHIACONFIG
DESCRIPTOR.message_types_by_name['DiscordConfig'] = _DISCORDCONFIG
DESCRIPTOR.message_types_by_name['MonitoringConfig'] = _MONITORINGCONFIG
DESCRIPTOR.message_types_by_name['DevelopmentConfig'] = _DEVELOPMENTCONFIG
DESCRIPTOR.message_types_by_name['ChiaTeaConfig'] = _CHIATEACONFIG
DESCRIPTOR.enum_types_by_name['LogLevel'] = _LOGLEVEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MachineConfig = _reflection.GeneratedProtocolMessageType('MachineConfig', (_message.Message,), {
  'DESCRIPTOR' : _MACHINECONFIG,
  '__module__' : 'chia_tea.protobuf.generated.config_pb2'
  # @@protoc_insertion_point(class_scope:chia_tea.protobuf.generated.config_pb2.MachineConfig)
  })
_sym_db.RegisterMessage(MachineConfig)

LoggingConfig = _reflection.GeneratedProtocolMessageType('LoggingConfig', (_message.Message,), {
  'DESCRIPTOR' : _LOGGINGCONFIG,
  '__module__' : 'chia_tea.protobuf.generated.config_pb2'
  # @@protoc_insertion_point(class_scope:chia_tea.protobuf.generated.config_pb2.LoggingConfig)
  })
_sym_db.RegisterMessage(LoggingConfig)

CopyConfig = _reflection.GeneratedProtocolMessageType('CopyConfig', (_message.Message,), {
  'DESCRIPTOR' : _COPYCONFIG,
  '__module__' : 'chia_tea.protobuf.generated.config_pb2'
  # @@protoc_insertion_point(class_scope:chia_tea.protobuf.generated.config_pb2.CopyConfig)
  })
_sym_db.RegisterMessage(CopyConfig)

ChiaConfig = _reflection.GeneratedProtocolMessageType('ChiaConfig', (_message.Message,), {
  'DESCRIPTOR' : _CHIACONFIG,
  '__module__' : 'chia_tea.protobuf.generated.config_pb2'
  # @@protoc_insertion_point(class_scope:chia_tea.protobuf.generated.config_pb2.ChiaConfig)
  })
_sym_db.RegisterMessage(ChiaConfig)

DiscordConfig = _reflection.GeneratedProtocolMessageType('DiscordConfig', (_message.Message,), {
  'DESCRIPTOR' : _DISCORDCONFIG,
  '__module__' : 'chia_tea.protobuf.generated.config_pb2'
  # @@protoc_insertion_point(class_scope:chia_tea.protobuf.generated.config_pb2.DiscordConfig)
  })
_sym_db.RegisterMessage(DiscordConfig)

MonitoringConfig = _reflection.GeneratedProtocolMessageType('MonitoringConfig', (_message.Message,), {

  'AuthConfig' : _reflection.GeneratedProtocolMessageType('AuthConfig', (_message.Message,), {
    'DESCRIPTOR' : _MONITORINGCONFIG_AUTHCONFIG,
    '__module__' : 'chia_tea.protobuf.generated.config_pb2'
    # @@protoc_insertion_point(class_scope:chia_tea.protobuf.generated.config_pb2.MonitoringConfig.AuthConfig)
    })
  ,

  'ServerConfig' : _reflection.GeneratedProtocolMessageType('ServerConfig', (_message.Message,), {
    'DESCRIPTOR' : _MONITORINGCONFIG_SERVERCONFIG,
    '__module__' : 'chia_tea.protobuf.generated.config_pb2'
    # @@protoc_insertion_point(class_scope:chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ServerConfig)
    })
  ,

  'ClientConfig' : _reflection.GeneratedProtocolMessageType('ClientConfig', (_message.Message,), {

    'SendUpdateEvery' : _reflection.GeneratedProtocolMessageType('SendUpdateEvery', (_message.Message,), {
      'DESCRIPTOR' : _MONITORINGCONFIG_CLIENTCONFIG_SENDUPDATEEVERY,
      '__module__' : 'chia_tea.protobuf.generated.config_pb2'
      # @@protoc_insertion_point(class_scope:chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig.SendUpdateEvery)
      })
    ,
    'DESCRIPTOR' : _MONITORINGCONFIG_CLIENTCONFIG,
    '__module__' : 'chia_tea.protobuf.generated.config_pb2'
    # @@protoc_insertion_point(class_scope:chia_tea.protobuf.generated.config_pb2.MonitoringConfig.ClientConfig)
    })
  ,
  'DESCRIPTOR' : _MONITORINGCONFIG,
  '__module__' : 'chia_tea.protobuf.generated.config_pb2'
  # @@protoc_insertion_point(class_scope:chia_tea.protobuf.generated.config_pb2.MonitoringConfig)
  })
_sym_db.RegisterMessage(MonitoringConfig)
_sym_db.RegisterMessage(MonitoringConfig.AuthConfig)
_sym_db.RegisterMessage(MonitoringConfig.ServerConfig)
_sym_db.RegisterMessage(MonitoringConfig.ClientConfig)
_sym_db.RegisterMessage(MonitoringConfig.ClientConfig.SendUpdateEvery)

DevelopmentConfig = _reflection.GeneratedProtocolMessageType('DevelopmentConfig', (_message.Message,), {
  'DESCRIPTOR' : _DEVELOPMENTCONFIG,
  '__module__' : 'chia_tea.protobuf.generated.config_pb2'
  # @@protoc_insertion_point(class_scope:chia_tea.protobuf.generated.config_pb2.DevelopmentConfig)
  })
_sym_db.RegisterMessage(DevelopmentConfig)

ChiaTeaConfig = _reflection.GeneratedProtocolMessageType('ChiaTeaConfig', (_message.Message,), {
  'DESCRIPTOR' : _CHIATEACONFIG,
  '__module__' : 'chia_tea.protobuf.generated.config_pb2'
  # @@protoc_insertion_point(class_scope:chia_tea.protobuf.generated.config_pb2.ChiaTeaConfig)
  })
_sym_db.RegisterMessage(ChiaTeaConfig)


# @@protoc_insertion_point(module_scope)
