# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chia_tea/protobuf/generated/machine_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='chia_tea/protobuf/generated/machine_info.proto',
  package='chia_tea.protobuf.generated.machine_info_pb2',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.chia_tea/protobuf/generated/machine_info.proto\x12,chia_tea.protobuf.generated.machine_info_pb2\"Z\n\x0bMachineInfo\x12\x12\n\nmachine_id\x18\x01 \x01(\x03\x12\x12\n\nip_address\x18\x02 \x01(\t\x12\x15\n\rtime_last_msg\x18\x03 \x01(\x01\x12\x0c\n\x04name\x18\x04 \x01(\tb\x06proto3'
)




_MACHINEINFO = _descriptor.Descriptor(
  name='MachineInfo',
  full_name='chia_tea.protobuf.generated.machine_info_pb2.MachineInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='machine_id', full_name='chia_tea.protobuf.generated.machine_info_pb2.MachineInfo.machine_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='chia_tea.protobuf.generated.machine_info_pb2.MachineInfo.ip_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_last_msg', full_name='chia_tea.protobuf.generated.machine_info_pb2.MachineInfo.time_last_msg', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='chia_tea.protobuf.generated.machine_info_pb2.MachineInfo.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=186,
)

DESCRIPTOR.message_types_by_name['MachineInfo'] = _MACHINEINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MachineInfo = _reflection.GeneratedProtocolMessageType('MachineInfo', (_message.Message,), {
  'DESCRIPTOR' : _MACHINEINFO,
  '__module__' : 'chia_tea.protobuf.generated.machine_info_pb2'
  # @@protoc_insertion_point(class_scope:chia_tea.protobuf.generated.machine_info_pb2.MachineInfo)
  })
_sym_db.RegisterMessage(MachineInfo)


# @@protoc_insertion_point(module_scope)
